@@ -121,10 +121,11 @@ def fc_start(option):
         option["reverse"] = True
         option["seed_id"] = option["query_id"]
         option["query_id"] = id_tmp
-        pairtmp = []
-        for pair in option["pairwise"]:
-            pairtmp.append((pair[1], pair[0]))
-        option["pairwise"] = pairtmp
+        if option["pairwise"]:
+            pairtmp = []
+            for pair in option["pairwise"]:
+                pairtmp.append((pair[1], pair[0]))
+            option["pairwise"] = pairtmp
         print("calculating backward scores...")
         r_results = fc_main(domain_count_2, query_proteome, seed_proteome, clan_dict, option)
         if option["phyloprofile"]:
@@ -683,7 +684,7 @@ def pb_create_jobs(graph, option):
 
 
 def pb_graph_traversal_sub(protein, search_features, weights, query_features, seed_proteome, a_s_f, a_q_f, clan_dict,
-                           query_clans, timelimit, query_graph, option, stack, search_graph, search_path_number):
+                           query_clans, timelimit, query_graph, option, search_graph, search_path_number, stack):
     """Sub function for multi-processing: This function does a depth-first search in the feature graph. The starting
      point in the graph is given in the stack.
 
@@ -746,7 +747,7 @@ def pb_graph_traversal_sub(protein, search_features, weights, query_features, se
 
 
 def pb_calc_sub(protein, search_features, weights, query_features, seed_proteome, a_s_f, a_q_f, clan_dict, query_clans,
-                timelimit, option, jobpaths, search_graph, search_path_number):
+                timelimit, option, search_graph, search_path_number, jobpaths):
     """Sub function for multiprocessing [2]: Goes through a list of (query) paths an evaluates them.
 
     :param protein: String that contains the identifier of the seed protein
